==> apache-asterixdb-0.9.2-source-release.zip: apache-asterixdb-0.9.2/asterix-app/src/test/java/org/apache/asterix/test/active/Action.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.test.active;

import org.apache.asterix.metadata.declared.MetadataProvider;
import org.apache.hyracks.api.exceptions.HyracksDataException;

abstract class Action {
    boolean done = false;
    HyracksDataException failure;

    void execute(MetadataProvider actorMdProvider) {
        try {
            doExecute(actorMdProvider);
        } catch (Exception e) {
            failure = HyracksDataException.create(e);
        }
        synchronized (this) {
            done = true;
            notifyAll();
        }
    }

    protected abstract void doExecute(MetadataProvider mdProvider) throws Exception;

    boolean hasFailed() {
        return failure != null;
    }

    HyracksDataException getFailure() {
        return failure;
    }

    synchronized void sync() throws InterruptedException {
        while (!done) {
            wait();
        }
    }

    boolean isDone() {
        return done;
    }
}

==> apache-asterixdb-0.9.6-source-release.zip: apache-asterixdb-0.9.6/asterix-app/src/test/java/org/apache/asterix/test/active/Action.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.test.active;

import org.apache.asterix.metadata.declared.MetadataProvider;
import org.apache.hyracks.api.exceptions.HyracksDataException;

public abstract class Action {
    boolean done = false;
    HyracksDataException failure;

    void execute(MetadataProvider actorMdProvider) {
        try {
            doExecute(actorMdProvider);
        } catch (Exception e) {
            failure = HyracksDataException.create(e);
        }
        synchronized (this) {
            done = true;
            notifyAll();
        }
    }

    protected abstract void doExecute(MetadataProvider mdProvider) throws Exception;

    public boolean hasFailed() {
        return failure != null;
    }

    public HyracksDataException getFailure() {
        return failure;
    }

    public synchronized void sync() throws InterruptedException {
        while (!done) {
            wait();
        }
    }

    public boolean isDone() {
        return done;
    }
}
